###################################################
### chunk number 1: load
###################################################
library(dlnm)


###################################################
### chunk number 2: dataset
###################################################
data(chicagoNMMAPS)


###################################################
### chunk number 3: internal.mkbasis
###################################################
basis.var <- mkbasis(1:5, knots=3)
basis.var


###################################################
### chunk number 4: internal.mkbasis2
###################################################
mkbasis(1:5, type="bs", df=4, degree=2)
mkbasis(1:5, type="lin", cenvalue=4)


###################################################
### chunk number 5: internal.mklagbasis
###################################################
mklagbasis(maxlag=5, type="poly", degree=3)
mklagbasis(maxlag=5, type="integer")


###################################################
### chunk number 6: internal.thr
###################################################
mkbasis(1:5, type="dthr", knots=c(2,3))
mkbasis(1:5, type="hthr", knots=3)
mkbasis(1:5, type="hthr", knots=c(2,3))


###################################################
### chunk number 7: internal.int
###################################################
mklagbasis(maxlag=10, type="strata", knots=c(4,7))
mklagbasis(maxlag=10, type="strata", knots=c(4,7), int=FALSE)


###################################################
### chunk number 8: internal.cen
###################################################
mkbasis(0:10, type="poly", degree=3)
mkbasis(0:10, type="poly", degree=3, cen=FALSE)


###################################################
### chunk number 9: example1crossbasis
###################################################
basis.pm <- crossbasis(chicagoNMMAPS$pm10, vartype="lin", lagtype="poly",
  lagdegree=4,cen=FALSE,maxlag=15)
basis.temp <- crossbasis(chicagoNMMAPS$temp, vardf=5, lagtype="strata",
  lagknots=1, cenvalue=21, maxlag=3)


###################################################
### chunk number 10: example1summary
###################################################
summary(basis.pm)


###################################################
### chunk number 11: example1model
###################################################
model <- glm(death ~  basis.pm + basis.temp, family=quasipoisson(), chicagoNMMAPS)


###################################################
### chunk number 12: example1pred
###################################################
pred.pm <- crosspred(basis.pm, model,at=0:20)


###################################################
### chunk number 13: example1slices
###################################################
crossplot(pred.pm, "slices", var=10,
  title="Effect of a 10-unit increase in PM10 along lags")


###################################################
### chunk number 14: example1effect
###################################################
pred.pm$allRRfit["10"]
cbind(pred.pm$allRRlow, pred.pm$allRRhigh)["10",]


###################################################
### chunk number 15: example1overall
###################################################
crossplot(pred.pm, "overall", label="PM10", ci="lines",
  title="Overall effect of PM10 over 15 days of lag")


###################################################
### chunk number 16: example2crossbasis
###################################################
basis.o3 <- crossbasis(chicagoNMMAPS$o3, vartype="hthr", varknots=40.3,
	lagtype="integer", maxlag=5)
basis.temp <- crossbasis(chicagoNMMAPS$temp, vartype="dthr", varknots=c(10,25),
	lagtype="strata", lagknots=c(2,7), maxlag=15)


###################################################
### chunk number 17: example2modelpred
###################################################
model <- glm(death ~  basis.o3 + basis.temp, family=quasipoisson(), chicagoNMMAPS)
pred.o3 <- crosspred(basis.o3, model,at=c(0:65,40.3,50.3))


###################################################
### chunk number 18: example2slices
###################################################
crossplot(pred.o3, "slices", var=50.3, ci="bars",
	title="Effect of a 10-unit increase in ozone along lags")


###################################################
### chunk number 19: example2overall
###################################################
crossplot(pred.o3,"overall",label="Ozone",
	title="Overall effect of ozone over 5 days of lag")


###################################################
### chunk number 20: example2noeval1 eval=FALSE
###################################################
## crossplot(pred.o3, "slices", var=50.3, ci="bars",
## 	title="Effect of a 10-unit increase in ozone along lags")
## crossplot(pred.o3,"overall",label="Ozone",
## 	title="Overall effect of ozone over 5 days of lag")	


###################################################
### chunk number 21: example2plot3d
###################################################
crossplot(pred.o3, label="Ozone", title="3D graph of ozone effect")


###################################################
### chunk number 22: example2plotcontour
###################################################
crossplot(pred.o3, "contour", label="Ozone", title="Contour graph of ozone effect")


###################################################
### chunk number 23: example2effect
###################################################
pred.o3$allRRfit["50.3"]
cbind(pred.o3$allRRlow, pred.o3$allRRhigh)["50.3",]


###################################################
### chunk number 24: example2noeval2 eval=FALSE
###################################################
## crossplot(pred.o3, label="Ozone", title="3D graph of ozone effect")
## crossplot(pred.o3, "contour", label="Ozone", title="Contour graph of ozone effect")


###################################################
### chunk number 25: example2overall2
###################################################
basis.o3 <- crossbasis(chicagoNMMAPS$o3, vartype="hthr", varknots=c(35,50),
	lagtype="integer", maxlag=5)
model <- update(model)
pred.o3 <- crosspred(basis.o3, model, at=c(0:65))
crossplot(pred.o3,"overall",label="Ozone",
	title="Overall effect of ozone over 5 days of lag")


###################################################
### chunk number 26: example3crossbasis
###################################################
basis.pm <- crossbasis(chicagoNMMAPS$pm10,vartype="lin", lagtype="strata",
  cen=FALSE, maxlag=1)
basis.temp <- crossbasis(chicagoNMMAPS$temp, vartype="bs", vardf=5, vardegree=2,
  lagdf=5, cenvalue=21, maxlag=30)


###################################################
### chunk number 27: example3noeval eval=FALSE
###################################################
## model <- glm(death ~  basis.pm + basis.temp, family=quasipoisson(), chicagoNMMAPS)
## pred.temp <- crosspred(basis.temp, model, at=-26:33, cumul=TRUE)
## crossplot(pred.temp, label="Temperature",
##   title="3D graph of temperature effect")
## crossplot(pred.temp, "contour", label="Temperature",
##   title="Contour graph of temperature effect")


###################################################
### chunk number 28: example3plot3d
###################################################
model <- glm(death ~  basis.pm + basis.temp, family=quasipoisson(), chicagoNMMAPS)
pred.temp <- crosspred(basis.temp, model, at=-26:33, cumul=TRUE)
crossplot(pred.temp, label="Temperature",
  title="3D graph of temperature effect")


###################################################
### chunk number 29: example3plotcontour
###################################################
crossplot(pred.temp, "contour", label="Temperature",
  title="Contour graph of temperature effect")


###################################################
### chunk number 30: example3overall
###################################################
crossplot(pred.temp, "overall", label="Temperature",
	title="Overall effect of temperature over 30 days of lag")


###################################################
### chunk number 31: example3slices
###################################################
crossplot(pred.temp, "slices", var=c(-20,0,27,33),
  lag=c(0,5,15,28), label="Temperature")


###################################################
### chunk number 32: example3cum
###################################################
crossplot(pred.temp, "slices", cumul=TRUE, ci="bars", var=-20,
  label="Temperature", title="Cumulative effect for -20C along lag")


###################################################
### chunk number 33: example3noeval2 eval=FALSE
###################################################
## crossplot(pred.temp, "slices", cum=TRUE, ci="bars", var=-20,
##   label="Temperature", title="Cumulative effect for -20C along lags")
## crossplot(pred.temp, "overall", label="Temperature",
## 	title="Overall effect of temperature over 30 days of lag")


###################################################
### chunk number 34: example3noeval3 eval=FALSE
###################################################
## crossplot(pred.temp, "slices", var=c(-20,0,27,33),
##   lag=c(0,5,15,28), label="Temperature")


###################################################
### chunk number 35: cleaning
###################################################
unlink("NMMAPS", recursive = TRUE)


